@@ -3,8 +3,9 @@ package ReRe::User;
 
 use Moose;
 use ReRe::Config;
+use Net::CIDR::Lite;
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 has file => (
     is       => 'rw',
@@ -40,14 +41,30 @@ sub _setup {
         $self->_add_user(
             $username => {
                 $password ? ( password => $password ) : (),
-                $allow ? ( allow => [ split(' ' , $allow ) ] ) : (),
-                roles => [ split(' ', $roles ) ]
+                $allow ? ( allow => [ split( ' ', $allow ) ] ) : (),
+                roles => [ split( ' ', $roles ) ]
             }
         );
     }
 
 }
 
+sub _check_cidr {
+    my $self  = shift;
+    my $ip    = shift;
+    my @allow = @_;
+
+    foreach my $network (@allow) {
+        my $cidr = Net::CIDR::Lite->new;
+        my $flag = 0;
+        eval {
+            $cidr->add($network);
+            $flag++ if $cidr->find($ip);
+        };
+        return 1 if $flag;
+    }
+}
+
 
 
 sub auth {
@@ -68,6 +85,7 @@ sub auth_ip {
         @allow = @{ $users{$user}{allow} } if defined( $users{$user}{allow} );
         @roles = @{ $users{$user}{roles} } if defined( $users{$user}{roles} );
         return $user if grep( /$ip|all/, @allow );
+        return $user if $self->_check_cidr( $ip, @allow );
     }
     return 0;
 }
@@ -89,6 +107,7 @@ sub _ip_has_role {
         @allow = @{ $users{$user}{allow} } if defined( $users{$user}{allow} );
         @roles = @{ $users{$user}{roles} } if defined( $users{$user}{roles} );
         return 1 if grep( /$ip|all/, @allow ) and grep( /$role|all/, @roles );
+        return 1 if $self->_check_cidr( $ip, @allow );
     }
     return 0;
 }
@@ -119,7 +138,7 @@ ReRe::User
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 METHODS
 
